# Cosmian Secure Computation Client

## Overview

Python client library for Cosmian Secure Computation API powered by Intel SGX.

## Install

```bash
pip install cosmian-secure-computation-client
```

## Documentation

See [https://docs.cosmian.com/secure_computation/](https://docs.cosmian.com/secure_computation/)